[Mesa-dev] [PATCH 3/3] util/disk_cache: scale cache according to filesystem size

Alan Swanson reiver at improbability.net
Mon Mar 6 16:17:32 UTC 2017


Select higher of current 1G default or 10% of filesystem where
cache is located. Note that cache for different architectures
are currently calculated separately so on x86 this could be
potentially 20%.

Quotas could be considered too.
---
 src/util/disk_cache.c | 11 ++++++++---
 1 file changed, 8 insertions(+), 3 deletions(-)

diff --git a/src/util/disk_cache.c b/src/util/disk_cache.c
index d2ae69911a..62ed417c76 100644
--- a/src/util/disk_cache.c
+++ b/src/util/disk_cache.c
@@ -31,6 +31,7 @@
 #include <sys/file.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/statvfs.h>
 #include <sys/mman.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -44,6 +45,7 @@
 #include "util/mesa-sha1.h"
 #include "util/ralloc.h"
 #include "main/errors.h"
+#include "util/macros.h"
 
 #include "disk_cache.h"
 
@@ -210,6 +212,7 @@ disk_cache_create(const char *gpu_name, const char *timestamp)
    uint64_t max_size;
    int fd = -1;
    struct stat sb;
+   struct statvfs vfs = { 0 };
    size_t size;
 
    /* If running as a users other than the real user disable cache */
@@ -371,9 +374,11 @@ disk_cache_create(const char *gpu_name, const char *timestamp)
       }
    }
 
-   /* Default to 1GB for maximum cache size. */
-   if (max_size == 0)
-      max_size = 1024*1024*1024;
+   /* Default to 1GB or 10% of filesystem for maximum cache size. */
+   if (max_size == 0) {
+      statvfs(path, &vfs);
+      max_size = MAX2(1024*1024*1024, vfs.f_blocks * vfs.f_bsize / 10);
+   }
 
    cache->max_size = max_size;
 
-- 
2.11.1



More information about the mesa-dev mailing list